Fitness Tools
=============

**Healthy Lifestyles With Python**

.. introduction-start

Introduction
------------

Thank you for your interest in this project.

For more in depth coverage see the `complete documentation`_.

.. _complete documentation: https://fitness-tools.readthedocs.io

Fitness Tools is a Python package that facilitates healthy lifestyles.
Whether you're a wellness professional, veteran gym rat, or just starting your fitness journey this package will benefit you.

While being healthy requires personal investment, it also requires some complex calculations like:

    1. If can lift **x** pounds for **y** repetitions how many pounds can I lift **z** times?

    2. If I need to eat **x** calories per day how many calories should I eat at each meal?
       How do these calories equate to grams of fat, protein, and carbohydrates per day and per meal?

    3. What is my bodyfat percentage base on skinfold measurements?

Before calculating everything by hand give this package a try.

.. introduction-end

.. quickstart-start

Quick Start
-----------

Fitness Tools is made with 100% pure, organic Python.

   - **There are no third party dependencies.**
   - **Only Supports Python 3.**

To get it now type this command:

.. code-block:: bash

   pip install fitness-tools


And you will be well on your way solving these problems:

.. quickstart-end

* `Calculating Body Composition`_

* `Guessing Repetitions`_

* `Macronutrient Assignments`_

.. _Calculating Body Composition: https://fitness-tools.readthedocs.io/en/latest/bodycomposition_details.html
.. _Guessing Repetitions: https://fitness-tools.readthedocs.io/en/latest/exercise_details.html
.. _Macronutrient Assignments: https://fitness-tools.readthedocs.io/en/latest/macronutrients_details.html


How To Contribute
-----------------

* First, read our `contributing guidelines`_.

* Next, read our changelog_ to see where this project has been.

* Finally, read our roadmap_ to see where this project is headed.

All skill levels are welcome and our maintainers will help you in whatever way we can.

.. _contributing guidelines: https://fitness-tools.readthedocs.io/en/latest/contributing-link.html
.. _changelog: https://fitness-tools.readthedocs.io/en/latest/changelog.html
.. _roadmap: https://fitness-tools.readthedocs.io/en/latest/roadmap.html

License
-------

This project is licensed under the `Apache 2.0 License`_.

.. _Apache 2.0 License: https://fitness-tools.readthedocs.io/en/latest/license-link.html
